package com.seeyon.cip.spi.capability.demo.sms;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.seeyon.cip.provider.api.common.ParameterService;
import com.seeyon.cip.provider.api.sms.SmsProviderService;
import com.seeyon.cip.provider.common.util.CipCapabilityInstanceUtils;
import com.seeyon.cip.provider.dto.CipProvideResultDto;
import com.seeyon.cip.provider.dto.sms.ShortMessageContentDto;
import com.seeyon.cip.provider.enums.CapabilityEnum;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;

/**
 * @Description:
 * @Author: lixuh
 * @DateTime: 2024-08-22 10:17
 */

@Slf4j
public class DemoSmsServiceImpl implements SmsProviderService  {


    /**
     * 获取spring中的类
     */
    private ParameterService parameterService = CipCapabilityInstanceUtils.getBean(ParameterService.class);


    /**
     * 发送短信：可以调用致远提供的发送短信服务 或者三方提供商提供的发送短信接口服务
     * @param invokeAppId  调用方应用名称
     * @param desPhone 接收短信的手机号：接受方为多个，则该传入的参数手机号以逗号分隔开
     * @param templateContent 要发送的短信内容参数：分为致远平台提供的模板 和 其他三方厂商提供的模板  短信模板code、模板名称、短信签名（短信服务提供商的名称）、语种等信息
     * @return CipProvideResultDto 对厂商提供商返回的响应数据的统一处理之后的返回结果对象：包括 返回数据、响应码、响应信息 操作是否成功的布尔值等信息
     */
    @Override
    public CipProvideResultDto sendShortMessage(String invokeAppId, String desPhone, ShortMessageContentDto templateContent) {
        // 获取页面自定义配置信息
        SmsProperties smsProperties = getSmsProperties();
        // 调用三方发送短信接口

        log.info("短信发送返回成功 or 失败 ?");
        // eg. 失败
        return CipProvideResultDto.fail();
    }

    /**
     * 获取页面自定义配置信息
     * @return SmsProperties
     */
    public SmsProperties getSmsProperties() {
        Map<String, String> map = parameterService.getProviderParameterMapRefresh(getCapabilityEnum().name(),getBeanName());
        ObjectMapper objectMapper = new ObjectMapper();
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
        return objectMapper.convertValue(map,SmsProperties.class);
    }

    /**
     * 服务特征所属的能力名称
     * @return 能力枚举
     */
    @Override
    public CapabilityEnum getCapabilityEnum() {
        return CapabilityEnum.Sms;
    }


    /**
     * 对应能力接入的服务提供商的名称
     *
     * @return 通道名称
     */
    @Override
    public String getDescription() {
        return "xx短信通道";
    }


    /**
     *  获取各通道code标识(限数字字母下划线).该能力下唯一, 避免和已有spi通道code重复
     *
     * @return eg。 "seeyon"
     *             "aliYun"
     *             ...
      */
    @Override
    public String getChannelCode() {
        return "seeyon";
    }


    /**
     * 对应的服务提供商的 自定义配置信息
     * map中 value为参数值，preset为是否预置，encryption为是否加密
     * @return 配置信息map
     */
    @Override
    public Map<String, String> getParamsMap() {
        Map<String, String> params = new HashMap<>();
        params.put("ak", "{\"value\":\"\",\"preset\":true,\"encryption\":false}");
        params.put("sk", "{\"value\":\"\",\"preset\":true,\"encryption\":true}");
        params.put("url", "{\"value\":\"\",\"preset\":true,\"encryption\":false}");
        return params;
    }
}
