package com.seeyon.cip.spi.capability.demo.sms;

import com.esotericsoftware.minlog.Log;
import com.seeyon.boot.exception.BusinessException;
import com.seeyon.boot.util.JsonUtils;
import com.seeyon.cip.provider.api.common.ParameterService;
import com.seeyon.cip.provider.api.sms.SmsTemplateAutoService;
import com.seeyon.cip.provider.common.util.CipCapabilityInstanceUtils;
import com.seeyon.cip.provider.dto.sms.SmsQueryTemplateDto;
import com.seeyon.cip.provider.dto.sms.SmsTemplateDto;
import com.seeyon.cip.provider.dto.sms.SmsTemplateQueryDto;
import org.apache.commons.collections4.CollectionUtils;

import java.util.List;
import java.util.Map;

/**
 * @Description:短信模板管理
 * @Author: lixuh
 * @DateTime: 2024-08-22 15:00
 */
public class DemoSmsTemplateAutoServiceImpl implements SmsTemplateAutoService {

    /**
     * 获取spring中的类
     */
    private ParameterService parameterService = CipCapabilityInstanceUtils.getBean(ParameterService.class);
    /**
     *
     * @param smsTemplateDto: 短信模板请求dto:包括：模板类型、模板编码、模板名称、模板语种、模板的内容、模板申请说明等信息
     * @return 返回值中： 从响应值中获取相关数据 向 smsTemplateDto对象中的短信平台返回模版编码、厂商平台模板内容 赋值
     */
    @Override
    public SmsTemplateDto addTemplate(SmsTemplateDto smsTemplateDto) {

        smsTemplateDto.setTemplateCode("001");
        smsTemplateDto.setProviderTemplateContent("此处为模板内容");
        Log.info("成功创建模板内容");
        return smsTemplateDto;
    }

    /**
     * 查看短信模板详情
     * @param smsTemplateQueryDto  查询短信模板详情需要传入的信息：短信模板的唯一标识：模板编号
     * @return
     */
    @Override
    public SmsQueryTemplateDto queryTemplate(SmsTemplateQueryDto smsTemplateQueryDto) {
        // eg.
        SmsQueryTemplateDto smsQueryTemplateDto = CipCapabilityInstanceUtils.getInstance(SmsQueryTemplateDto.class);
        smsQueryTemplateDto.setReason("此处传入响应数据中的申请原因说明");
        smsQueryTemplateDto.setTemplateStatus("响应数据中的模板状态：例如：审核通过");
        Log.info("成功查询到模板内容并返回");
        return smsQueryTemplateDto;
    }

    /**
     * 编辑/更新 短信模板
     * @param smsTemplateDto 需要更新的短信模板的相关参数
     * @return
     * @throws BusinessException
     */
    @Override
    public SmsTemplateDto updateTemplate(SmsTemplateDto smsTemplateDto) throws BusinessException {
        Log.info("短信模板更新成功");
        return smsTemplateDto;
    }

    /**
     * 删除短信模板
     * @param templateCode 要删除的短信模板的唯一标识：短信模板编号
     *
     */
    @Override
    public void deleteTemplate(String templateCode) throws BusinessException {
        Log.info("短信模板删除成功");

    }

    /**
     * 按需实现
     * 订阅回调通知
     * @param message
     * @return
     */
    @Override
    public SmsQueryTemplateDto subscribeTemplate(String message) {

        List<Map<String, Object>> list = JsonUtils.toList(message);
        if (CollectionUtils.isNotEmpty(list)) {
            Map<String, Object> dataMap = list.get(0);
            SmsQueryTemplateDto dto = new SmsQueryTemplateDto();

            dto.setTemplateCode(String.valueOf(dataMap.get("template_code")));
            dto.setReason(String.valueOf(dataMap.get("reason")));
           // ...

            return dto;
        }
        return null;
    }

    /**
     * 对应短信实现对应的厂家标识(javaBean)
     *
     * @return
     */
    @Override
    public String provider() {
        return "demoSmsServiceImpl";
    }
}
